==> openGion_dev_5.6.8.0.zip: opengion/uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF09S.sql <==
/****************************************************************************/
/* GF09 ( ｼｰｹﾝｽ定義 )                                                       */
/*                                                                          */
/* Created : 2013/09/03 10:23:35                                            */
/****************************************************************************/
CREATE TABLE GF09 (
   SYSTEM_ID    VARCHAR2 ( 10 )                         NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (  1 )                         NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , SEQNAME      VARCHAR2 ( 50 )                         NOT NULL            /*  30 ｼｰｹﾝｽ名      */
 , INCREBY      NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  40 ｲﾝｸﾘﾒﾝﾄ      */
 , STARTVAL     NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  50 開始値       */
 , MINVAL       NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  60 最小値       */
 , MAXVAL       NUMBER   (  9 )     DEFAULT 999999999   NOT NULL            /*  70 最大値       */
 , FGCYCLE      VARCHAR2 (  1 )     DEFAULT '1'         NOT NULL            /*  80 ｻｲｸﾙﾌﾗｸﾞ     */
 , SUCACHE      NUMBER   (  7 )     DEFAULT 0           NOT NULL            /*  90 ｷｬｯｼｭ数      */
 , TABLE_NAME   VARCHAR2 ( 50 )                                             /* 100 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR2 ( 30 )                                             /* 110 項目         */
 , UNIQ         NUMBER   (  9 )     DEFAULT 0           NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (  1 )     DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 ( 14 )                                             /* 820 登録日時     */
 , PGSET        VARCHAR2 ( 10 )                                             /* 830 作成PG       */
 , PGPSET       VARCHAR2 ( 10 )                                             /* 840 作成親PG     */
 , USRSET       VARCHAR2 ( 10 )                                             /* 850 作成社員     */
 , DYUPD        VARCHAR2 ( 14 )                                             /* 860 更新日時     */
 , PGUPD        VARCHAR2 ( 10 )                                             /* 870 更新PG       */
 , PGPUPD       VARCHAR2 ( 10 )                                             /* 880 更新親PG     */
 , USRUPD       VARCHAR2 ( 10 )                                             /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

CREATE SEQUENCE GF09S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF09T00 
  BEFORE INSERT ON GF09
  FOR EACH ROW 
  BEGIN 
    SELECT GF09S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion_dev_5.6.9.0.zip: opengion/uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF09S.sql <==
/****************************************************************************/
/* GF09 ( ｼｰｹﾝｽ定義 )                                                       */
/*                                                                          */
/* Created : 2013/09/30 18:24:49                                            */
/****************************************************************************/
CREATE TABLE GF09 (
   SYSTEM_ID    VARCHAR2 ( 10 )                         NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (  1 )                         NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , SEQNAME      VARCHAR2 ( 50 )                         NOT NULL            /*  30 ｼｰｹﾝｽ名      */
 , INCREBY      NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  40 ｲﾝｸﾘﾒﾝﾄ      */
 , STARTVAL     NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  50 開始値       */
 , MINVAL       NUMBER   (  9 )     DEFAULT 1           NOT NULL            /*  60 最小値       */
 , MAXVAL       NUMBER              DEFAULT 999999999   NOT NULL            /*  70 最大値       */
 , FGCYCLE      VARCHAR2 (  1 )     DEFAULT '1'         NOT NULL            /*  80 ｻｲｸﾙﾌﾗｸﾞ     */
 , SUCACHE      NUMBER   (  7 )     DEFAULT 0           NOT NULL            /*  90 ｷｬｯｼｭ数      */
 , TABLE_NAME   VARCHAR2 ( 50 )                                             /* 100 ﾃｰﾌﾞﾙ名      */
 , CLM          VARCHAR2 ( 30 )                                             /* 110 項目         */
 , UNIQ         NUMBER   (  9 )     DEFAULT 0           NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (  1 )     DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 ( 14 )                                             /* 820 登録日時     */
 , PGSET        VARCHAR2 ( 10 )                                             /* 830 作成PG       */
 , PGPSET       VARCHAR2 ( 10 )                                             /* 840 作成親PG     */
 , USRSET       VARCHAR2 ( 10 )                                             /* 850 作成社員     */
 , DYUPD        VARCHAR2 ( 14 )                                             /* 860 更新日時     */
 , PGUPD        VARCHAR2 ( 10 )                                             /* 870 更新PG       */
 , PGPUPD       VARCHAR2 ( 10 )                                             /* 880 更新親PG     */
 , USRUPD       VARCHAR2 ( 10 )                                             /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K PCTINCREASE 0 );

CREATE SEQUENCE GF09S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF09T00 
  BEFORE INSERT ON GF09
  FOR EACH ROW 
  BEGIN 
    SELECT GF09S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
